@@ -1,5 +1,6 @@
-from findCPcore.AbstractMetabolicModel import *
-from findCPcore.MetabolicModel import *
+
+__version__ = "0.1.1"
+
 from findCPcore.CobraMetabolicModel import *
 from findCPcore.State import *
 from findCPcore.Spreadsheet import *
